@@ -4,7 +4,7 @@ use chrono::prelude::*;
 use ratatui::{backend::Backend, Terminal};
 
 use crate::{
-    cli::RenderOpts,
+    cli::{Opt, RenderOpts},
     display::{
         components::{HeaderDetails, HelpText, Layout, Table},
         UIState,
@@ -26,20 +26,22 @@ impl<B> Ui<B>
 where
     B: Backend,
 {
-    pub fn new(terminal_backend: B, opts: RenderOpts) -> Self {
+    pub fn new(terminal_backend: B, opts: &Opt) -> Self {
         let mut terminal = Terminal::new(terminal_backend).unwrap();
         terminal.clear().unwrap();
         terminal.hide_cursor().unwrap();
         let state = {
             let mut state = UIState::default();
-            state.cumulative_mode = opts.total_utilization;
+            state.interface_name = opts.interface.clone();
+            state.unit_family = opts.render_opts.unit_family.into();
+            state.cumulative_mode = opts.render_opts.total_utilization;
             state
         };
         Ui {
             terminal,
             state,
             ip_to_host: Default::default(),
-            opts,
+            opts: opts.render_opts,
         }
     }
     pub fn output_text(&mut self, write_to_stdout: &mut (dyn FnMut(String) + Send)) {
@@ -123,28 +125,21 @@ where
     }
 
     pub fn draw(&mut self, paused: bool, show_dns: bool, elapsed_time: Duration, ui_offset: usize) {
-        let state = &self.state;
-        let children = self.get_tables_to_display();
+        let layout = Layout {
+            header: HeaderDetails {
+                state: &self.state,
+                elapsed_time,
+                paused,
+            },
+            children: self.get_tables_to_display(),
+            footer: HelpText { paused, show_dns },
+        };
         self.terminal
-            .draw(|frame| {
-                let size = frame.size();
-                let total_bandwidth = HeaderDetails {
-                    state,
-                    elapsed_time,
-                    paused,
-                };
-                let help_text = HelpText { paused, show_dns };
-                let layout = Layout {
-                    header: total_bandwidth,
-                    children,
-                    footer: help_text,
-                };
-                layout.render(frame, size, ui_offset);
-            })
+            .draw(|frame| layout.render(frame, frame.size(), ui_offset))
             .unwrap();
     }
 
-    fn get_tables_to_display(&self) -> Vec<Table<'static>> {
+    fn get_tables_to_display(&self) -> Vec<Table> {
         let opts = &self.opts;
         let mut children: Vec<Table> = Vec::new();
         if opts.processes {
