@@ -1,5 +1,4 @@
 use std::{
-    cell::RefCell,
     cmp,
     collections::{HashMap, HashSet, VecDeque},
     hash::Hash,
@@ -7,9 +6,11 @@ use std::{
     net::{IpAddr, Ipv4Addr, Ipv6Addr},
 };
 
-use log::warn;
-
-use crate::network::{Connection, LocalSocket, Utilization};
+use crate::{
+    display::BandwidthUnitFamily,
+    mt_log,
+    network::{Connection, LocalSocket, Utilization},
+};
 
 static RECALL_LENGTH: usize = 5;
 static MAX_BANDWIDTH_ITEMS: usize = 1000;
@@ -78,81 +79,24 @@ pub struct UtilizationData {
 
 #[derive(Default)]
 pub struct UIState {
+    /// The interface name in single-interface mode. `None` means all interfaces.
+    pub interface_name: Option<String>,
     pub processes: Vec<(String, NetworkData)>,
     pub remote_addresses: Vec<(IpAddr, NetworkData)>,
     pub connections: Vec<(Connection, ConnectionData)>,
     pub total_bytes_downloaded: u128,
     pub total_bytes_uploaded: u128,
     pub cumulative_mode: bool,
+    pub unit_family: BandwidthUnitFamily,
     pub utilization_data: VecDeque<UtilizationData>,
     pub processes_map: HashMap<String, NetworkData>,
     pub remote_addresses_map: HashMap<IpAddr, NetworkData>,
     pub connections_map: HashMap<Connection, ConnectionData>,
     /// Used for reducing logging noise.
-    known_orphan_sockets: RefCell<VecDeque<LocalSocket>>,
+    known_orphan_sockets: VecDeque<LocalSocket>,
 }
 
 impl UIState {
-    fn get_proc_name<'a>(
-        &self,
-        connections_to_procs: &'a HashMap<LocalSocket, String>,
-        local_socket: &LocalSocket,
-    ) -> Option<&'a String> {
-        let name = connections_to_procs
-            // direct match
-            .get(local_socket)
-            // IPv4-mapped IPv6 addresses
-            .or_else(|| {
-                let swapped: IpAddr = match local_socket.ip {
-                    IpAddr::V4(v4) => v4.to_ipv6_mapped().into(),
-                    IpAddr::V6(v6) => v6.to_ipv4_mapped()?.into(),
-                };
-                connections_to_procs.get(&LocalSocket {
-                    ip: swapped,
-                    ..*local_socket
-                })
-            })
-            // address unspecified
-            .or_else(|| {
-                connections_to_procs.get(&LocalSocket {
-                    ip: Ipv4Addr::UNSPECIFIED.into(),
-                    ..*local_socket
-                })
-            })
-            .or_else(|| {
-                connections_to_procs.get(&LocalSocket {
-                    ip: Ipv6Addr::UNSPECIFIED.into(),
-                    ..*local_socket
-                })
-            });
-
-        if name.is_none() {
-            let mut orphans = self.known_orphan_sockets.borrow_mut();
-            // only log each orphan connection once
-            if !orphans.contains(local_socket) {
-                // newer connections go in the front so that searches are faster
-                // basically recency bias
-                orphans.push_front(*local_socket);
-                orphans.truncate(10_000); // arbitrary maximum backlog
-
-                match connections_to_procs.iter().find(
-                    |(&LocalSocket { port, protocol, .. }, _)| {
-                        port == local_socket.port && protocol == local_socket.protocol
-                    },
-                ) {
-                    Some((lookalike, name)) => {
-                        warn!(
-                            r#""{name}" owns a similar looking connection, but its local ip doesn't match."#
-                        );
-                        warn!("Looking for: {local_socket}; found: {lookalike}");
-                    }
-                    None => warn!("Cannot determine which process owns {local_socket}."),
-                };
-            }
-        }
-
-        name
-    }
     pub fn update(
         &mut self,
         connections_to_procs: HashMap<LocalSocket, String>,
@@ -195,18 +139,46 @@ impl UIState {
                 total_bytes_downloaded += connection_info.total_bytes_downloaded;
                 total_bytes_uploaded += connection_info.total_bytes_uploaded;
 
-                let data_for_process = if let Some(process_name) =
-                    self.get_proc_name(connections_to_procs, &connection.local_socket)
-                {
-                    connection_data.process_name = process_name.clone();
-                    processes
-                        .entry(connection_data.process_name.clone())
-                        .or_default()
-                } else {
-                    connection_data.process_name = String::from("<UNKNOWN>");
-                    processes
-                        .entry(connection_data.process_name.clone())
-                        .or_default()
+                let data_for_process = {
+                    let local_socket = connection.local_socket;
+                    let process_name = get_proc_name(connections_to_procs, &local_socket);
+
+                    // only log each orphan connection once
+                    if process_name.is_none() && !self.known_orphan_sockets.contains(&local_socket)
+                    {
+                        // newer connections go in the front so that searches are faster
+                        // basically recency bias
+                        self.known_orphan_sockets.push_front(local_socket);
+                        self.known_orphan_sockets.truncate(10_000); // arbitrary maximum backlog
+
+                        match connections_to_procs
+                            .iter()
+                            .find(|(&LocalSocket { port, protocol, .. }, _)| {
+                                port == local_socket.port && protocol == local_socket.protocol
+                            })
+                            .and_then(|(local_conn_lookalike, name)| {
+                                network_utilization
+                                    .connections
+                                    .keys()
+                                    .find(|conn| &conn.local_socket == local_conn_lookalike)
+                                    .map(|conn| (conn, name))
+                            }) {
+                            Some((lookalike, name)) => {
+                                mt_log!(
+                                    warn,
+                                    r#""{name}" owns a similar looking connection, but its local ip doesn't match."#
+                                );
+                                mt_log!(warn, "Looking for: {connection:?}; found: {lookalike:?}");
+                            }
+                            None => {
+                                mt_log!(warn, "Cannot determine which process owns {connection:?}");
+                            }
+                        };
+                    }
+
+                    let process_display_name = process_name.unwrap_or("<UNKNOWN>").to_owned();
+                    connection_data.process_name = process_display_name.clone();
+                    processes.entry(process_display_name).or_default()
                 };
 
                 data_for_process.total_bytes_downloaded += connection_info.total_bytes_downloaded;
@@ -250,6 +222,40 @@ impl UIState {
     }
 }
 
+fn get_proc_name<'a>(
+    connections_to_procs: &'a HashMap<LocalSocket, String>,
+    local_socket: &LocalSocket,
+) -> Option<&'a str> {
+    connections_to_procs
+        // direct match
+        .get(local_socket)
+        // IPv4-mapped IPv6 addresses
+        .or_else(|| {
+            let swapped: IpAddr = match local_socket.ip {
+                IpAddr::V4(v4) => v4.to_ipv6_mapped().into(),
+                IpAddr::V6(v6) => v6.to_ipv4_mapped()?.into(),
+            };
+            connections_to_procs.get(&LocalSocket {
+                ip: swapped,
+                ..*local_socket
+            })
+        })
+        // address unspecified
+        .or_else(|| {
+            connections_to_procs.get(&LocalSocket {
+                ip: Ipv4Addr::UNSPECIFIED.into(),
+                ..*local_socket
+            })
+        })
+        .or_else(|| {
+            connections_to_procs.get(&LocalSocket {
+                ip: Ipv6Addr::UNSPECIFIED.into(),
+                ..*local_socket
+            })
+        })
+        .map(String::as_str)
+}
+
 fn merge_bandwidth<K, V>(self_map: &mut HashMap<K, V>, other_map: HashMap<K, V>)
 where
     K: Eq + Hash,
