@@ -1,9 +1,12 @@
-use std::{ffi::OsStr, net::IpAddr, process::Command, sync::OnceLock};
+use std::{ffi::OsStr, net::IpAddr, process::Command};
 
-use log::warn;
+use once_cell::sync::Lazy;
 use regex::Regex;
 
-use crate::network::{LocalSocket, Protocol};
+use crate::{
+    mt_log,
+    network::{LocalSocket, Protocol},
+};
 
 #[allow(dead_code)]
 #[derive(Debug, Clone)]
@@ -16,9 +19,6 @@ pub struct RawConnection {
     pub process_name: String,
 }
 
-static CONNECTION_REGEX_ONCE: OnceLock<Regex> = OnceLock::new();
-static LISTEN_REGEX: OnceLock<Regex> = OnceLock::new();
-
 fn get_null_addr(ip_type: &str) -> &str {
     if ip_type.contains('4') {
         "0.0.0.0"
@@ -29,10 +29,6 @@ fn get_null_addr(ip_type: &str) -> &str {
 
 impl RawConnection {
     pub fn new(raw_line: &str) -> Option<RawConnection> {
-        let connection_regex = CONNECTION_REGEX_ONCE
-            .get_or_init(|| Regex::new(r"\[?([^\s\]]*)\]?:(\d+)->\[?([^\s\]]*)\]?:(\d+)").unwrap());
-        let listen_regex =
-            LISTEN_REGEX.get_or_init(|| Regex::new(r"\[?([^\s\[\]]*)\]?:(.*)").unwrap());
         // Example row
         // com.apple   664     user  198u  IPv4 0xeb179a6650592b8d      0t0    TCP 192.168.1.187:58535->1.2.3.4:443 (ESTABLISHED)
         let columns: Vec<&str> = raw_line.split_ascii_whitespace().collect();
@@ -57,8 +53,13 @@ impl RawConnection {
         let connection_str = columns[8];
         // "(LISTEN)" or "(ESTABLISHED)",  this column may or may not be present
         // let connection_state = columns[9];
+
+        static CONNECTION_REGEX: Lazy<Regex> =
+            Lazy::new(|| Regex::new(r"\[?([^\s\]]*)\]?:(\d+)->\[?([^\s\]]*)\]?:(\d+)").unwrap());
+        static LISTEN_REGEX: Lazy<Regex> =
+            Lazy::new(|| Regex::new(r"\[?([^\s\[\]]*)\]?:(.*)").unwrap());
         // If this socket is in a "connected" state
-        if let Some(caps) = connection_regex.captures(connection_str) {
+        if let Some(caps) = CONNECTION_REGEX.captures(connection_str) {
             // Example
             // 192.168.1.187:64230->0.1.2.3:5228
             // *:*
@@ -76,7 +77,7 @@ impl RawConnection {
                 process_name,
             };
             Some(connection)
-        } else if let Some(caps) = listen_regex.captures(connection_str) {
+        } else if let Some(caps) = LISTEN_REGEX.captures(connection_str) {
             let local_ip = if caps.get(1).unwrap().as_str() == "*" {
                 get_null_addr(ip_type)
             } else {
@@ -120,15 +121,24 @@ impl RawConnection {
         let process = &self.process_name;
 
         let Some(ip) = self.get_local_ip() else {
-            warn!(r#"Failed to get the local IP of a connection belonging to "{process}"."#);
+            mt_log!(
+                warn,
+                r#"Failed to get the local IP of a connection belonging to "{process}"."#
+            );
             return None;
         };
         let Some(port) = self.get_local_port() else {
-            warn!(r#"Failed to get the local port of a connection belonging to "{process}"."#);
+            mt_log!(
+                warn,
+                r#"Failed to get the local port of a connection belonging to "{process}"."#
+            );
             return None;
         };
         let Some(protocol) = self.get_protocol() else {
-            warn!(r#"Failed to get the protocol of a connection belonging to "{process}"."#);
+            mt_log!(
+                warn,
+                r#"Failed to get the protocol of a connection belonging to "{process}"."#
+            );
             return None;
         };
 
